<?php

define('WP_ROOT_DIR', dirname(__DIR__));

/**
 * Use Dotenv to set required environment variables and load .env file in root
 */
$DotEnv = new Dotenv\Dotenv(WP_ROOT_DIR);
$DotEnv->load();
$DotEnv->required(array('DB_NAME', 'DB_USER', 'DB_PASSWORD', 'WP_HOME'));


/**
 * Set up our global environment constant and load its config first
 * Default: production
 */
define('WP_ENV', getenv('WP_ENV') ? getenv('WP_ENV') : 'production');

define('DB_NAME', getenv('DB_NAME'));
define('DB_USER', getenv('DB_USER') ? getenv('DB_USER') : 'root');
define('DB_PASSWORD', getenv('DB_PASSWORD') ? getenv('DB_PASSWORD') : '');
define('DB_HOST', getenv('DB_HOST') ? getenv('DB_HOST') : 'localhost');

define('WP_MEMORY_LIMIT', getenv('WP_MEMORY_LIMIT'));

define('WP_HOME', getenv('WP_HOME'));
define('WP_SITEURL', WP_HOME);


$envConfig = __DIR__ . '/environments/' . WP_ENV . '.php';

if (file_exists($envConfig)) {
    require_once($envConfig);
} else {
    /* Production */
    define('SAVEQUERIES', false);
    define('WP_DEBUG', false);
    ini_set('display_errors', 0);
    define('WP_DEBUG_DISPLAY', false);
    define('WP_DEBUG_LOG', false);
    define('SCRIPT_DEBUG', false);
}

/**
 * Custom Content Directory
 */
define('WP_CONTENT_DIR', WP_ROOT_DIR . '/content');
define('WP_CONTENT_URL', WP_HOME . '/content');

/**
 * DB settings
 */
define('DB_CHARSET', 'utf8');
define('DB_COLLATE', '');
$table_prefix = getenv('DB_PREFIX');

/**
 * Authentication Unique Keys and Salts
 */
define('AUTH_KEY', getenv('AUTH_KEY'));
define('SECURE_AUTH_KEY', getenv('SECURE_AUTH_KEY'));
define('LOGGED_IN_KEY', getenv('LOGGED_IN_KEY'));
define('NONCE_KEY', getenv('NONCE_KEY'));
define('AUTH_SALT', getenv('AUTH_SALT'));
define('SECURE_AUTH_SALT', getenv('SECURE_AUTH_SALT'));
define('LOGGED_IN_SALT', getenv('LOGGED_IN_SALT'));
define('NONCE_SALT', getenv('NONCE_SALT'));

/**
 * Network
 */
define('WP_ALLOW_MULTISITE', false);

if (WP_ALLOW_MULTISITE == true) {
    $wpHome = explode('/', WP_HOME);
    $domainCurrentSite = $wpHome[2];

    define('MULTISITE', false);
    define('SUBDOMAIN_INSTALL', false);
    define('DOMAIN_CURRENT_SITE', $domainCurrentSite);
    define('PATH_CURRENT_SITE', '/');
    define('SITE_ID_CURRENT_SITE', 1);
    define('BLOG_ID_CURRENT_SITE', 1);
}

/**
 * Custom Settings
 */
define('DISALLOW_FILE_EDIT', true);

/**
 * Bootstrap WordPress
 */
if (!defined('ABSPATH')) {
    define('ABSPATH', WP_ROOT_DIR . '/wp/');
}
